@@ -10,9 +10,14 @@ use File::Spec::Functions ':ALL';
 
 use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '1.20';
+	$VERSION = '1.21';
 	@ISA     = 'Exporter';
-	@EXPORT  = qw{ test_db mirror_db connect_ok create_ok };
+	@EXPORT  = qw{
+		test_db
+		create_ok
+		mirror_db
+		connect_ok
+	};
 }
 
 
